@@ -29,8 +29,7 @@ use Scalar::Util qw(weaken blessed);
 use Evented::Object::EventFire;
 use Evented::Object::Collection;
 
-# always use 2 decimals. change other packages too.
-our $VERSION = '5.63';
+our $VERSION = '5.64';
 
 # creates a new evented object.
 sub new {
@@ -543,7 +542,7 @@ BEGIN {
 
 =head1 NAME
 
-B<Evented::Object> - a base class which allows you to attach callbacks to
+B<Evented::Object> - base class which allows you to attach callbacks to
 objects and then fire events on them.
 
 =head1 SYNOPSIS
@@ -624,124 +623,24 @@ Whereas many event systems involve globally unique event names, Evented::Object
 allows you to attach events on specific objects. The event callbacks,
 priority options, and other data are stored within the object itself.
 
-=head2 Glossary
-
-These terms are used throughout the Evented::Object documentation.
-
-=over
-
-=item B<Evented::Object>
-
-This base class, providing methods for managing events.
-
-=item B<Evented object> - C<$eo>
-
-Refers to any object instance of Evented::Object or a package which inherits
-from it.
-
-See L</"Evented object methods">.
-
-=item B<Callback>
-
-Event responders, known as callbacks, consist of a code reference and sometimes
-additional options describing how and when they should be executed.
-
-They are executed in descending order by priority. Numerically larger priorities
-are called first. This allows you to place a certain callback in front of or
-behind another.
-
-=item B<Fire object> - C<$fire> or C<$event>
-
-An object representing an event fire.
-
-The fire object provides methods for fetching information related to the current
-event fire. It also provides an interface for modifying the behavior of the
-remaining callbacks.
-
-Fire objects are specific to the particular event fire, not the event. If you
-fire the same event twice in a row, the event object used the first time will
-not be the same as the second time. Therefore, all modifications made by the
-fire object's methods apply only to the callbacks remaining in this particular
-fire. For example, C<< $fire->cancel($callback) >> will only cancel the supplied
-callback once.
-
-See L</"Fire object methods">.
-
-=item B<Collection> - C<$col> or C<$collection>
-
-An object representing a group of callbacks waiting to be fired.
-
-Sometimes it is useful to prepare an event fire before actually calling it.
-This way, you can provide special options for the fire. Collections are returned
-by the 'prepare' methods.
-
- $eo->prepare(event_name => @args)->fire(some_fire_option => $value);
-
-See L</"Collection methods">.
-
-=item B<Listener object>
-
-An evented object that receives event notifications from another evented object.
-
-Additional evented objects can be registered as "listeners," which allows them
-to respond to the events of another evented object.
-
-Consider a scenario where you have a class whose objects represent a farm. You
-have another class which represents a cow. You would like to use the same
-callback for all of the moos that occur on the farm, regardless of which cow
-initiated it.
-
-Rather than attaching an event callback to every cow, you can instead make the
-farm a listener of the cow. Then, you can attach a single callback to your farm.
-If your cow's event for mooing is C<moo>, your farm's event for mooing is
-C<cow.moo>.
-
-B<Fire objects and listeners>
-
-When an event is fired on an object, the same fire object is used for callbacks
-belonging to both the evented object and its listening objects. Therefore,
-callback names should be unique not only to the listener object but to the
-object being listened on as well.
-
-You should also note the values of the fire object:
-
-=over
-
-=item *
-
-B<< $fire->event_name >>: the name of the event from the perspective of the
-listener; i.e. C<cow.moo> (NOT C<moo>)
-
-=item *
-
-B<< $fire->object >>: the object being listened to; i.e. C<$cow> (NOT C<$farm>)
-
-=back
-
-This also means that stopping the event from a listener object will cancel all
-remaining callbacks, including those belonging to the evented object.
-
-=back
-
-Evented::Object's included core packages are prefixed with C<Evented::Object::>.
-Other packages which are specifically designed for use with Evented::Object are
-prefixed with C<Evented::>.
-
-=head1 Evented object methods
+=head1 MANAGING CALLBACKS
 
 The Evented::Object package provides several convenient methods for managing an
 event-driven object.
 
 =head2 Evented::Object->new()
 
-Creates a new Evented::Object. Typically, this method is overriden by a child
-class of Evented::Object.
+Creates a new Evented::Object.
+
+Typically, this method is overriden by a child class of Evented::Object.
 
  my $eo = Evented::Object->new();
 
 =head2 $eo->register_callback($event_name => \&callback, %options)
 
-Attaches an event callback the object. When the specified event is fired, each
+Attaches an event callback the object.
+
+When the specified event is fired, each
 of the callbacks registered using this method will be called by descending
 priority order (numerically higher priority numbers are called first.)
 
@@ -755,59 +654,61 @@ B<Parameters>
 
 =item *
 
-B<event_name>: the name of the event.
+B<$event_name> - name of the event.
 
 =item *
 
-B<callback>: a CODE reference to be called when the event is fired.
+B<\&callback> - CODE reference to be called when the event is fired.
 
 =item *
 
-B<options>: I<optional>, a hash (NOT a hash reference) of any of the below
+B<%options> - I<optional>, a hash (NOT a hash reference) of any of the below
 options.
 
 =back
 
-B<%options - event handler options>
+B<%options> - event handler options
 
-All of these options are B<optional>, but the use of a callback name is B<highly
-recommended>.
+All of these options are I<optional>, but the use of a callback name is
+B<highly recommended>.
 
 =over
 
 =item *
 
-B<name>: the name of the callback being registered. must be unique to this
+B<name> - name of the callback being registered. must be unique to this
 particular event.
 
 =item *
 
-B<priority>: a numerical priority of the callback.
+B<priority> - numerical priority of the callback.
 
 =item *
 
-B<before>: the name of a callback or an array reference of callback names to
+B<before> - name of a callback or an array reference of callback names to
 precede.
 
 =item *
 
-B<after>: the name of a callback or an array reference of callback names to
+B<after> - name of a callback or an array reference of callback names to
 succeed.
 
 =item *
 
-B<data>: any data that will be stored as C<< $fire->callback_data >> as the
+B<data> - data that will be stored as C<< $fire->callback_data >> as the
 callback is fired. If C<data> is a hash reference, its values can be fetched
 conveniently with C<< $fire->callback_data('key') >>.
 
 =item *
 
-B<with_eo>: if true, the evented object will prepended to the argument list.
+B<with_eo> - if true, the evented object will prepended to the argument list
+(which is not the default behavior). note that this is enabled automatically
+when using the odd-argument version.
 
 =item *
 
-B<no_fire_obj>: if true, the fire object will not be prepended to the argument
-list.
+B<no_fire_obj> - if true, the L<fire object|Evented::Object::EventFire> will not
+be prepended to the argument list (which is the default behavior).
 
 =back
 
@@ -841,7 +742,9 @@ See the above method specification for parameters and supported options.
 
 =head2 $eo->register_callbacks(@events)
 
-Registers several events at once. The arguments should be a list of hash
+Registers several event callbacks at once.
+
+The arguments should be a list of hash
 references. These references take the same options as
 C<< ->register_callback() >>. Returns a list of return values in the order that
 the events were specified.
@@ -857,7 +760,7 @@ B<Parameters>
 
 =item *
 
-B<events>: an array of hash references to pass to C<< ->register_callback() >>.
+B<@events> - array of hash references to pass to C<< ->register_callback() >>.
 
 =back
 
@@ -865,7 +768,7 @@ B<events>: an array of hash references to pass to C<< ->register_callback() >>.
 
 Deletes all callbacks registered for the supplied event.
 
-Returns a true value if any events were deleted, false otherwise.
+Returns number of callbacks deleted, false if none.
 
  $eo->delete_event('myEvent');
 
@@ -875,15 +778,15 @@ B<Parameters>
 
 =item *
 
-B<event_name>: the name of the event.
+B<$event_name> - name of the event.
 
 =back
 
-=head2 $eo->delete_callback($event_name)
+=head2 $eo->delete_callback($event_name, $callback_name)
 
 Deletes an event callback from the object with the given callback name.
 
-Returns a true value if any events were deleted, false otherwise.
+Returns true if a callback was deleted.
 
  $eo->delete_callback(myEvent => 'my.callback');
 
@@ -893,19 +796,32 @@ B<Parameters>
 
 =item *
 
-B<event_name>: the name of the event.
+B<$event_name> - name of the event.
 
 =item *
 
-B<callback_name>: the name of the callback being removed.
+B<$callback_name> - name of the callback being removed.
 
 =back
 
+=head2 $eo->delete_all_events()
+
+Deletes all events and all callbacks from the object.
+
+If you know that an
+evented object will no longer be used in your program, by calling this method
+you can be sure that no cyclical references from within callbacks will cause the
+object to be leaked.
+
+=head1 FIRING EVENTS
+
 =head2 $eo->fire_event($event_name => @arguments)
 
 Fires the specified event, calling each callback that was registered with
 C<< ->register_callback() >> in descending order of their priorities.
 
+Returns the L<fire object|Evented::Object::EventFire>.
+
  $eo->fire_event('some_event');
 
  $eo->fire_event(some_event => $some_argument, $some_other_argument);
@@ -916,11 +832,11 @@ B<Parameters>
 
 =item *
 
-B<event_name>: the name of the event being fired.
+B<$event_name> - name of the event being fired.
 
 =item *
 
-B<arguments>: I<optional>, list of arguments to pass to event callbacks.
+B<@arguments> - I<optional>, list of arguments to pass to event callbacks.
 
 =back
 
@@ -932,6 +848,8 @@ C<< ->register_callback() >> in descending order of their priorities.
 Then, all callbacks for the event are deleted. This method is useful for
 situations where an event will never be fired more than once.
 
+Returns the L<fire object|Evented::Object::EventFire>.
+
  $eo->fire_once('some_event');
  $eo->fire_event(some_event => $some_argument, $some_other_argument);
  # the second does nothing because the first deleted the callbacks
@@ -942,77 +860,24 @@ B<Parameters>
 
 =item *
 
-B<event_name>: the name of the event being fired.
+B<$event_name> - name of the event being fired.
 
 =item *
 
-B<arguments>: I<optional>, list of arguments to pass to event callbacks.
-
-=back
-
-=head2 $eo->add_listener($other_eo, $prefix)
-
-Makes the passed evented object a listener of this evented object. See the
-"listener objects" section for more information on this feature.
-
- $cow->add_listener($farm, 'cow');
-
-B<Parameters>
-
-=over
-
-=item *
-
-B<other_eo>: the evented object that will listen.
-
-=item *
-
-B<prefix>: a string that event names will be prefixed with on the listener.
+B<@arguments> - I<optional>, list of arguments to pass to event callbacks.
 
 =back
 
 =head2 $eo->fire_events_together(@events)
 
 The C<fire_events_together()> function can be used as a method on evented
-objects. See the documentation for the function in L</"Procedural functions">.
-
-=head2 $eo->delete_listener($other_eo)
-
-Removes a listener of this evented object. See the "listener objects" section
-for more information on this feature.
-
- $cow->delete_listener($farm, 'cow');
-
-B<Parameters>
-
-=over
-
-=item *
-
-B<other_eo>: the evented object that will listen.
-
-=item *
-
-B<prefix>: a string that event names will be prefixed with on the listener.
-
-=back
-
-=head2 $eo->delete_all_events()
-
-Deletes all events and all callbacks from the object. If you know that an
-evented object will no longer be used in your program, by calling this method
-you can be sure that no cyclical references from within callbacks will cause the
-object to be leaked.
-
-=head1 Preparation methods
-
-Callbacks can be prepared before being fired. This is most useful for firing
-events with special fire options.
+objects. See the documentation for the function in L</"PROCEDURAL FUNCTIONS">.
 
 =head2 $eo->prepare_event(event_name => @arguments)
 
-Prepares a single event for firing. Returns a collection object representing the
-callbacks for the event.
+Prepares a single event for firing.
+
+Returns an L<Evented::Object::Collection> representing the pending callbacks.
 
  # an example using the fire option return_check.
  $eo->prepare_event(some_event => @arguments)->fire('return_check');
@@ -1021,6 +886,8 @@ callbacks for the event.
 
 The preparatory method equivalent to C<< ->fire_events_together >>.
 
+Returns an L<Evented::Object::Collection> representing the pending callbacks.
+
 =head2 $eo->prepare(...)
 
 A smart method that uses the best guess between C<< ->prepare_event >> and
@@ -1034,13 +901,102 @@ C<< ->prepare_together >>.
     [ some_event => @arguments ],
     [ some_other => @other_arg ]
  );
+ 
+=head1 LISTENERS
 
-=head1 Class monitors
+An evented object can I<listen> for event notifications from another evented
+object using the method L</"$eo-E<gt>add_listener($other_eo, $prefix)">.
+
+Consider a scenario where you have a class whose objects represent a farm. You
+have another class which represents a cow. You would like to use the same
+callback for all of the moos that occur on the farm, regardless of which cow
+initiated it.
+
+Rather than attaching an event callback to every cow, you can instead make the
+farm a listener of the cow. Then, you can attach a single callback to your farm.
+If your cow's event for mooing is C<moo>, your farm's event for any mooing is
+C<cow.moo>.
+
+When an event is fired on an object, the same fire object is used for callbacks
+belonging to both the evented object and its listening objects. Therefore,
+callback names should be unique not only to the listener object but to the
+object being listened on as well.
+
+You should also note the values of the
+L<fire object|Evented::Object::EventFire>:
+
+=over
+
+=item *
+
+B<< $fire->event_name >> - name of the event from the perspective of the
+listener; i.e. C<cow.moo> (NOT C<moo>)
+
+=item *
+
+B<< $fire->object >> - object being listened to; i.e. C<$cow> (NOT C<$farm>)
+
+=back
+
+This also means that stopping the event from a listener object will cancel
+I<all> remaining callbacks.
+
+=head2 $eo->add_listener($other_eo, $prefix)
+
+Makes the passed evented object a listener of this evented object.
+
+See L</"LISTENERS">.
+
+ $cow->add_listener($farm, 'cow');
+
+B<Parameters>
+
+=over
+
+=item *
+
+B<$other_eo> - evented object that will listen.
+
+=item *
+
+B<$prefix> - string that event names will be prefixed with on the listener.
+
+=back
+
+=head2 $eo->delete_listener($other_eo)
+
+Removes a listener of this evented object.
+
+See L</"LISTENERS">.
+
+ $cow->delete_listener($farm);
+
+B<Parameters>
+
+=over
+
+=item *
+
+B<$other_eo> - evented object that will listen.
+
+=back
+
+=head1 CLASS MONITORS
+
+An evented object can be registered as a "monitor" of a specific class/package.
+
+I<All> event callbacks that are added from that class to I<any> evented object
+of I<any> type will trigger an event on the monitor object.
+
+An example scenario of when this might be useful is an evented object for
+debugging all events being registered by a certain package. It would log all of
+them, making it easier to find a problem.
 
 =head2 $eo->monitor_events($pkg)
 
-Registers an evented object as the class monitor for a specific package. See the
-section above for more details on class monitors and their purpose.
+Registers an evented object as the class monitor for a specific package.
+
+See L</"CLASS MONITORS">.
 
  my $some_eo  = Evented::Object->new;
  my $other_eo = Evented::Object->new;
@@ -1062,15 +1018,16 @@ section above for more details on class monitors and their purpose.
 
 =item *
 
-B<pkg>: a package whose event activity you wish to monitor.
+B<$pkg> - package whose event activity you wish to monitor.
 
 =back
 
 =head2 $eo->stop_monitoring($pkg)
 
 Removes an evented object from its current position as a monitor for a specific
-package. See the section above for more details on class monitors and their
-purpose.
+package.
+
+See L</"CLASS MONITORS">.
 
  $some_eo->stop_monitoring('Some::Class');
 
@@ -1078,28 +1035,31 @@ purpose.
 
 =item *
 
-B<pkg>: a package whose event activity you're monitoring.
+B<$pkg> - package whose event activity you're monitoring.
 
 =back
 
-=head1 Procedural functions
+=head1 PROCEDURAL FUNCTIONS
 
 The Evented::Object package provides some functions for use. These functions
 typically are associated with more than one evented object or none at all.
 
 =head2 fire_events_together(@events)
 
-Fires multiple events at the same time. This allows you to fire multiple similar
+Fires multiple events at the same time.
+
+This allows you to fire multiple similar
 events on several evented objects at the same time. It essentially pretends that
 the callbacks are all for the same event and all on the same object.
 
 It follows priorities throughout all of the events and all of the objects, so it
 is ideal for firing similar or identical events on multiple objects.
 
-The same fire object is used throughout this entire routine. This means that
-callback names must unique among all of these objects and events. It also means
-that stopping an event from any callback will cancel all remaining callbacks,
-regardless to which event or which object they belong.
+The same L<fire object|Evented::Object::EventFire> is used throughout.
+This means that callback names must unique among all of these
+objects and events. It also means that stopping an event from any callback will
+cancel all remaining callbacks, regardless to which event or which object they
+belong.
 
 The function takes a list of array references in the form of:
 C<< [ $evented_object, event_name => @arguments ] >>
@@ -1133,6 +1093,8 @@ object on which the method was called.
      [ $other_eo, some_event => @arguments ],
      [            some_other => @other_arg ] # no object, falls back to $eo
  );
+ 
+Returns the L<fire object|Evented::Object::EventFire>.
 
 B<Parameters>
 
@@ -1140,14 +1102,14 @@ B<Parameters>
 
 =item *
 
-B<events>: an array of events in the form of
+B<@events> - array of events in the form of
 C<< [$eo, event_name => @arguments] >>.
 
 =back
 
 =head2 safe_fire($eo, $event_name, @args)
 
-Safely fires an event. In other words, if the C<< $eo >> is not an evented
+Safely fires an event. In other words, if the C<$eo> is not an evented
 object or is not blessed at all, the call will be ignored. This eliminates the
 need to use C<blessed()> and C<< ->isa() >> on a value for testing whether it is
 an evented object.
@@ -1160,311 +1122,22 @@ B<Parameters>
 
 =item *
 
-B<eo>: the evented object.
+B<$eo> - evented object.
 
 =item *
 
-B<event_name>: the name of the event.
+B<$event_name> - name of the event.
 
 =item *
 
-B<args>: the arguments for the event fire.
+B<@args> - arguments for the event fire.
 
 =back
 
-=head1 Collection methods
+=head1 ALIASES
 
-L</Collections> are returned by the 'prepare' methods. They represent a group of
-callbacks that are about to be fired.
-
-=head2 $col->fire(@options)
-
-Fires the pending callbacks with the specified options, if any. If the callbacks
-have not yet been sorted, they are sorted before the event is fired.
-
- $eo->prepare(some_event => @arguments)->fire('safe');
-
-B<Parameters>
-
-=over
-
-=item *
-
-B<options>: I<optional>, a mixture of boolean and key:value options for the
-event fire.
-
-=back
-
-B<@options>
-
-=over
-
-=item *
-
-B<caller>: I<requires value>, use an alternate C<[caller 1]> value for the event
-fire. This is typically only used internally.
-
-=item *
-
-B<return_check>: I<boolean>, if true, the event will yield that it was stopped
-if any of the callbacks return a false value. Note however that if one callbacks
-returns false, the rest will still be called. The fire object will only yield
-stopped status after all callbacks have been called and any number of them
-returned false.
-
-=item *
-
-B<safe>: I<boolean>, wrap all callback calls in C<eval> for safety. if any of
-them fail, the event will be stopped at that point with the error.
-
-=item *
-
-B<fail_continue>: I<boolean>, if C<safe> above is enabled, this tells the fire
-to continue even if one of the callbacks fails. This could be dangerous if any
-of the callbacks expected a previous callback to be done when it actually
-failed.
-
-=item *
-
-B<data>: I<requires value>, a scalar value that can be fetched by
-C<< $fire->data >> from within the callbacks. Good for data that might be useful
-sometimes but not frequently enough to deserve a spot in the argument list. If
-C<data> is a hash reference, its values can be fetched conveniently with
-C<< $fire->data('key') >>.
-
-=back
-
-=head2 $col->sort
-
-Sorts the callbacks according to C<priority>, C<before>, and C<after> options.
-
-=head1 Fire object methods
-
-L</"Fire objects"> are passed to all callbacks of an Evented::Object (unless the
-silent parameter was specified.) Fire objects contain information about the
-event itself, the callback, the caller of the event, event data, and more.
-
-=head2 $fire->object
-
-Returns the evented object.
-
- $fire->object->delete_event('myEvent');
-
-=head2 $fire->caller
-
-Returns the value of C<caller(1)> from within the C<< ->fire() >> method.
-This allows you to determine from where the event was fired.
-
- my $name   = $fire->event_name;
- my @caller = $fire->caller;
- say "Package $caller[0] line $caller[2] called event $name";
-
-=head2 $fire->stop($reason)
-
-Cancels all remaining callbacks. This stops the rest of the event firing. After
-a callback calls $fire->stop, the name of that callback is stored as
-C<< $fire->stopper >>.
-
-If the event has already been stopped, this method returns the reason for which
-the fire was stopped or "unspecified" if no reason was given.
-
- # ignore messages from trolls
- if ($user eq 'noah') {
-     # user is a troll.
-     # stop further callbacks.
-     return $fire->stop;
- }
-
-=over
-
-=item *
-
-B<reason>: I<optional>, the reason for stopping the event fire.
-
-=back
-
-=head2 $fire->stopper
-
-Returns the callback which called C<< $fire->stop >>.
-
- if ($fire->stopper) {
-     say 'Fire was stopped by '.$fire->stopper;
- }
-
-=head2 $fire->exception
-
-If the event was fired with the C<< safe >> option, it is possible that an
-exception occurred in one (or more if C<< fail_continue >> enabled) callbacks.
-This method returns the last exception that occurred or C<< undef >> if none
-did.
-
- if (my $e = $fire->exception) {
-    say "Exception! $e";
- }
-
-=head2 $fire->called($callback)
-
-If no argument is supplied, returns the number of callbacks called so far,
-including the current one. If a callback argument is supplied, returns whether
-that particular callback has been called.
-
- say $fire->called, 'callbacks have been called so far.';
-
- if ($fire->called('some.callback')) {
-     say 'some.callback has been called already.';
- }
-
-B<Parameters>
-
-=over
-
-=item *
-
-B<callback>: I<optional>, the callback being checked.
-
-=back
-
-=head2 $fire->pending($callback)
-
-If no argument is supplied, returns the number of callbacks pending to be
-called, excluding the current one. If a callback  argument is supplied, returns
-whether that particular callback is pending for being called.
-
- say $fire->pending, ' callbacks are left.';
-
- if ($fire->pending('some.callback')) {
-     say 'some.callback will be called soon (unless it gets canceled)';
- }
-
-B<Parameters>
-
-=over
-
-=item *
-
-B<callback>: I<optional>, the callback being checked.
-
-=back
-
-=head2 $fire->cancel($callback)
-
-Cancels the supplied callback once.
-
- if ($user eq 'noah') {
-     # we don't love noah!
-     $fire->cancel('send.hearts');
- }
-
-B<Parameters>
-
-=over
-
-=item *
-
-B<callback>: the callback to be cancelled.
-
-=back
-
-=head2 $fire->return_of($callback)
-
-Returns the return value of the supplied callback.
-
- if ($fire->return_of('my.callback')) {
-     say 'my.callback returned a true value';
- }
-
-B<Parameters>
-
-=over
-
-=item *
-
-B<callback>: the desired callback.
-
-=back
-
-=head2 $fire->last
-
-Returns the most recent previous callback called.
-This is also useful for determining which callback was the last to be called.
-
- say $fire->last, ' was called before this one.';
-
- my $fire = $eo->fire_event('myEvent');
- say $fire->last, ' was the last callback called.';
-
-=head2 $fire->last_return
-
-Returns the last callback's return value.
-
- if ($fire->last_return) {
-     say 'the callback before this one returned a true value.';
- }
- else {
-     die 'the last callback returned a false value.';
- }
-
-=head2 $fire->event_name
-
-Returns the name of the event.
-
- say 'the event being fired is ', $fire->event_name;
-
-=head2 $fire->callback_name
-
-Returns the name of the current callback.
-
- say 'the current callback being called is ', $fire->callback_name;
-
-=head2 $fire->callback_priority
-
-Returns the priority of the current callback.
-
- say 'the priority of the current callback is ', $fire->callback_priority;
-
-=head2 $fire->callback_data($key)
-
-Returns the data supplied to the callback when it was registered, if any. If the
-data is a hash reference, an optional key parameter can specify a which value to
-fetch.
-
- say 'my data is ', $fire->callback_data;
- say 'my name is ', $fire->callback_data('name');
-
-B<Parameters>
-
-=over
-
-=item *
-
-B<key>: I<optional>, a key to fetch a value if the data registered was a hash.
-
-=back
-
-=head2 $fire->data($key)
-
-Returns the data supplied to the collection when it was fired, if any. If the
-data is a hash reference, an optional key parameter can specify a which value to
-fetch.
-
- say 'fire data is ', $fire->data;
- say 'fire time was ', $fire->data('time');
-
-B<Parameters>
-
-=over
-
-=item *
-
-B<key>: I<optional>, a key to fetch a value if the data registered was a hash.
-
-=back
-
-=head1 Aliases
-
-A number of aliases exist for convenience, but some of the names are rather
-broad. For that reason, they are only recommended for use when you are sure that
-other subclassing will not interfere.
+A number of aliases exist for convenience, but please only use them if you're
+certain that other subclassing will not interfere.
 
 =head2 $eo->on(...)
 
@@ -1492,37 +1165,6 @@ Alias for C<< $eo->register_callbacks() >>.
 
 Alias for C<< $fire->object >>.
 
-=head1 ADVANCED FEATURES
-
-=head2 Registering callbacks to package names
-
-The methods C<< ->register_callback() >>, C<< ->delete_event() >>,
-C<< ->delete_callback >>, etc. can be called in the form of
-C<< MyClass->method() >>. Evented::Object will store these callbacks in the
-package's symbol table.
-
-Any object of this class will borrow these callbacks from the class. They will
-be incorporated into the callback collection as though they were registered
-directly on the object.
-
-Note that events cannot be fired on a class, only on evented objects.
-
-Note that if an evented object is blessed to a subclass of a class with
-callbacks registered to it, the object will NOT inherit the callbacks associated
-with the parent class. Callbacks registered to classes ONLY apply to objects
-directly blessed to the class.
-
-=head2 Class monitors
-
-An evented object can be registered as a "monitor" of a specific class/package.
-
-I<All> event callbacks that are added from that class to I<any> evented object
-of I<any> type will trigger an event on the monitor object.
-
-An example scenario of when this might be useful is an evented object for
-debugging all events being registered by a certain package. It would log all of
-them, making it easier to find a problem.
-
 =head1 AUTHOR
 
 L<Mitchell Cooper|https://github.com/cooper> <cooper@cpan.org>
@@ -1530,4 +1172,4 @@ L<Mitchell Cooper|https://github.com/cooper> <cooper@cpan.org>
 Copyright E<copy> 2011-2017. Released under BSD license.
 
 Comments, complaints, and recommendations are accepted. Bugs may be reported on
-L<RT|https://rt.cpan.org/Public/Dist/Display.html?Name=Evented-Object>.
+L<GitHub|https://github.com/cooper/evented-object/issues>.
